@@ -8,28 +8,30 @@
 # @black_format
 
 """The implementation for the GithubChange."""
+
 from __future__ import annotations
 
 import json
 from functools import cached_property
-from typing import TYPE_CHECKING, ClassVar, Dict, List, Tuple
+from typing import ClassVar, Dict, List, Tuple
 
 from autotransform.batcher.base import Batch
 from autotransform.change.base import Change, ChangeName, ChangeState
+from autotransform.config import get_repo_config_relative_path
 from autotransform.item.base import FACTORY as item_factory
+from autotransform.schema.builder import FACTORY as schema_builder_factory
+from autotransform.schema.schema import AutoTransformSchema
+from autotransform.util.enums import SchemaType
 from autotransform.util.github import GithubUtils, PullRequest
 
-if TYPE_CHECKING:
-    from autotransform.schema.schema import AutoTransformSchema
-
 
 class GithubChange(Change):
-    """A Change representing a pull request on a Github repo.
+    """A Change representing a Pull Request on a Github repo.
 
     Attributes:
         full_github_name (str): The fully qualified name of the Github Repo the
-            pull request is against.
-        pull_number (int): The number for the pull request.
+            Pull Request is against.
+        pull_number (int): The number for the Pull Request.
         name (ClassVar[ChangeName]): The name of the Component.
     """
 
@@ -53,7 +55,29 @@ class GithubChange(Change):
             AutoTransformSchema: The Schema used to produce the Change.
         """
 
-        return self._body_data[0]
+        schema_name = self.get_schema_name()
+        map_file_path = f"{get_repo_config_relative_path()}/schema_map.json"
+        with open(map_file_path, "r", encoding="UTF-8") as map_file:
+            schema_map = json.loads(map_file.read())
+        data = schema_map[schema_name]
+        schema_type = SchemaType(data["type"])
+        if schema_type == SchemaType.BUILDER:
+            schema = schema_builder_factory.get_instance({"name": data["target"]}).build()
+        else:
+            with open(data["target"], "r", encoding="utf-8") as schema_file:
+                schema = AutoTransformSchema.from_data(json.loads(schema_file.read()))
+        assert schema_name == schema.config.schema_name
+
+        return schema
+
+    def get_schema_name(self) -> str:
+        """Gets the name of the Schema that produced the Change.
+
+        Returns:
+            str: The name of the Schema.
+        """
+
+        return self._pull_request.branch.split("/")[1].replace("_", " ")
 
     def get_state(self) -> ChangeState:
         """Gets the current state of the Change. Caches the state in _state to prevent
@@ -84,51 +108,129 @@ class GithubChange(Change):
             return ChangeState.CHANGES_REQUESTED
         return ChangeState.OPEN
 
-    def get_created_timestamp(self) -> int:
-        """Returns the timestamp when the pull request was created.
+    def get_labels(self) -> List[str]:
+        """Gets all labels for a Change.
 
         Returns:
-            int: The timestamp in seconds when the pull request was created.
+            List[str]: The list of labels.
+        """
+
+        return self._pull_request.get_labels()
+
+    def get_reviewers(self) -> List[str]:
+        """Gets all reviewers for a Change.
+
+        Returns:
+            List[str]: The list of reviewers.
+        """
+
+        return self._pull_request.get_reviewers()
+
+    def get_team_reviewers(self) -> List[str]:
+        """Gets all team reviewers for a Change.
+
+        Returns:
+            List[str]: The list of team reviewers.
+        """
+
+        return self._pull_request.get_team_reviewers()
+
+    def get_created_timestamp(self) -> int:
+        """Returns the timestamp when the Pull Request was created.
+
+        Returns:
+            int: The timestamp in seconds when the Pull Request was created.
         """
 
         return self._pull_request.get_created_at()
 
     def get_last_updated_timestamp(self) -> int:
-        """Returns the timestamp when the pull request was last updated.
+        """Returns the timestamp when the Pull Request was last updated.
 
         Returns:
-            int: The timestamp in seconds when the pull request was last updated.
+            int: The timestamp in seconds when the Pull Request was last updated.
         """
 
         return self._pull_request.get_updated_at()
 
-    def _merge(self) -> bool:
-        """Merges the pull request and deletes the branch.
-
-        Returns:
-            bool: Whether the merge was completed successfully.
-        """
-
-        merged = self._pull_request.merge()
-        if not merged:
-            return False
-        return self._pull_request.delete_branch()
-
-    def abandon(self) -> bool:
-        """Close the pull request and delete the associated branch.
+    def _abandon(self) -> bool:
+        """Close the Pull Request and delete the associated branch.
 
         Returns:
             bool: Whether the abandon was completed successfully.
         """
 
-        closed = self._pull_request.close()
-        if not closed:
+        if not self._pull_request.close():
             return False
         return self._pull_request.delete_branch()
 
+    def _add_labels(self, labels: List[str]) -> bool:
+        """Adds labels to an outstanding Change.
+
+        Args:
+            labels (List[str]): The labels to add.
+
+        Returns:
+            bool: Whether the labels were added successfully.
+        """
+
+        self._pull_request.add_labels(labels)
+        return True
+
+    def _add_reviewers(self, reviewers: List[str], team_reviewers: List[str]) -> bool:
+        """Adds reviewers to an outstanding Change.
+
+        Args:
+            reviewers (List[str]): The reviewers to add.
+            team_reviewers (List[str]): Any team reviewers to add.
+
+        Returns:
+            bool: Whether the reviewers were added successfully.
+        """
+
+        self._pull_request.add_reviewers(reviewers, team_reviewers)
+        return True
+
+    def _comment(self, body: str) -> bool:
+        """Comments on an outstanding Change.
+
+        Args:
+            body (str): The body of the comment.
+
+        Returns:
+            bool: Whether the comment was successful.
+        """
+
+        self._pull_request.create_comment(body)
+        return True
+
+    def _merge(self) -> bool:
+        """Merges the Pull Request and deletes the branch.
+
+        Returns:
+            bool: Whether the merge was completed successfully.
+        """
+
+        if not self._pull_request.merge():
+            return False
+        return self._pull_request.delete_branch()
+
+    def _remove_label(self, label: str) -> bool:
+        """Removes a label from an outstanding Change.
+
+        Args:
+            label (str): The label to remove.
+
+        Returns:
+            bool: Whether the label was removed successfully.
+        """
+
+        self._pull_request.remove_label(label)
+        return True
+
     @cached_property
     def _pull_request(self) -> PullRequest:
-        """Gets the pull request as a cached property.
+        """Gets the Pull Request as a cached property.
 
         Returns:
             PullRequest: The PullRequest.
@@ -138,16 +240,13 @@ class GithubChange(Change):
 
     @cached_property
     def _body_data(self) -> Tuple[AutoTransformSchema, Batch]:
-        """Loads the Schema and Batch data for the GithubChange.
+        """Loads the Schema and Batch data for the GithubChange as a cached property.
 
         Returns:
             Tuple[AutoTransformSchema, Batch]: The Schema and Batch contained
                 in the PullRequest's Body.
         """
 
-        # pylint: disable=import-outside-toplevel
-        from autotransform.schema.schema import AutoTransformSchema
-
         data: Dict[str, List[str]] = {"schema": [], "batch": []}
         cur_line_placement = None
         for line in self._pull_request.body.splitlines():
