@@ -16,15 +16,18 @@ from enum import Enum
 from typing import ClassVar, Sequence
 
 from autotransform.item.base import Item
-from autotransform.util.component import NamedComponent, ComponentFactory, ComponentImport
+from autotransform.util.component import ComponentFactory, ComponentImport, NamedComponent
 
 
 class InputName(str, Enum):
-    """A simple enum for 1:1 Input to type mapping."""
+    """A simple enum for mapping."""
 
     DIRECTORY = "directory"
     EMPTY = "empty"
     GIT_GREP = "git_grep"
+    INLINE = "inline"
+    INLINE_FILE = "inline_file"
+    INLINE_GENERIC = "inline_generic"
 
 
 class Input(NamedComponent):
@@ -59,6 +62,15 @@ FACTORY = ComponentFactory(
         InputName.GIT_GREP: ComponentImport(
             class_name="GitGrepInput", module="autotransform.input.gitgrep"
         ),
+        InputName.INLINE: ComponentImport(
+            class_name="InlineInput", module="autotransform.input.inline"
+        ),
+        InputName.INLINE_FILE: ComponentImport(
+            class_name="InlineFileInput", module="autotransform.input.inline"
+        ),
+        InputName.INLINE_GENERIC: ComponentImport(
+            class_name="InlineGenericInput", module="autotransform.input.inline"
+        ),
     },
     Input,  # type: ignore [misc]
     "input.json",
