@@ -12,8 +12,10 @@
 from __future__ import annotations
 
 import json
-from typing import Any, ClassVar, Dict, List, Mapping, Optional, Sequence
+from copy import deepcopy
+from typing import TYPE_CHECKING, Any, ClassVar, Dict, List, Mapping, Optional, Sequence
 
+from pydantic import BaseModel  # pylint: disable=no-name-in-module
 from pydantic import Field
 
 import autotransform.schema
@@ -26,14 +28,37 @@ from autotransform.repo.base import RepoName
 from autotransform.repo.git import GitRepo
 from autotransform.util.github import GithubUtils
 
+if TYPE_CHECKING:
+    from autotransform.schema.schema import AutoTransformSchema
+
+
+# pylint: disable=too-few-public-methods
+class GithubRepoBatchMetadata(BaseModel):
+    """_summary_
+
+    Attributes:
+        body (str): The body of the Pull Request to make.
+        labels(optional, List[str]): The labels to add to the Pull Request. Defaults to [].
+        reviewers(optional, List[str]): The reviewers to request for the Pull Request.
+            Defaults to [].
+        team_reviewers(optional, List[str]): The team reviewers to request for the Pull Request.
+            Defaults to [].
+    """
+
+    body: str
+    labels: List[str] = Field(default_factory=list)
+    reviewers: List[str] = Field(default_factory=list)
+    team_reviewers: List[str] = Field(default_factory=list)
+
 
 class GithubRepo(GitRepo):
     """A Repo that provides support for submitting changes as a pull request against
     a Github repo.
 
     Attributes:
-        base_branch_name (str): The name of the base branch for the repository.
         full_github_name (str): The fully qualified name of the Github Repo.
+        commit_repo (optional, Optional[str]): The repo from which to generate a Pull Request. Used
+            if creating a Pull Request from a fork. Defaults to None.
         hide_automation_info (bool, optional): Whether to hide information on how automation was
             done from the pull request body. Defaults to False.
         hide_autotransform_docs (bool, optional): Whether to hide links to AutoTransform docs
@@ -45,8 +70,9 @@ class GithubRepo(GitRepo):
         name (ClassVar[RepoName]): The name of the component.
     """
 
-    base_branch_name: str
     full_github_name: str
+
+    commit_repo: Optional[str] = None
     hide_automation_info: bool = False
     hide_autotransform_docs: bool = False
     labels: List[str] = Field(default_factory=list)
@@ -55,6 +81,24 @@ class GithubRepo(GitRepo):
 
     name: ClassVar[RepoName] = RepoName.GITHUB
 
+    def has_outstanding_change(self, batch: Batch) -> bool:
+        """Checks the state of the repo to see whether an outstanding Change
+        for the Batch exists.
+
+        Args:
+            batch (Batch): The Batch to check for.
+
+        Returns:
+            bool: Whether an outstanding Change exists.
+        """
+
+        refs = self._local_repo.git.ls_remote(
+            "--heads",
+            self._local_repo.remote().name,
+            GitRepo.get_branch_name(batch["title"]),
+        )
+        return refs != ""
+
     def submit(
         self,
         batch: Batch,
@@ -72,7 +116,7 @@ class GithubRepo(GitRepo):
         """
 
         title = GitRepo.get_commit_message(batch["title"])
-        batch_metadata = batch.get("metadata", {})
+        batch_metadata = GithubRepoBatchMetadata.parse_obj(batch.get("metadata", {}))
 
         self.commit(batch["title"], change is not None)
 
@@ -84,19 +128,21 @@ class GithubRepo(GitRepo):
 
         self._local_repo.git.push(remote.name, "-u", commit_branch)
 
-        body = batch_metadata.get("body", None)
-
         if self.hide_automation_info:
             automation_info = ""
         else:
-            automation_info = "\n\n" + self.get_automation_info(batch)
+            automation_info = "\n\n" + self.get_automation_info(autotransform.schema.current, batch)
+
+        if self.commit_repo is not None:
+            head = f"{self.commit_repo}:"
+        else:
+            head = ""
 
-        assert body is not None, "All pull requests must have a body."
         pull_request = GithubUtils.get(self.full_github_name).create_pull_request(
             title,
-            f"{str(body)}{automation_info}",
+            f"{str(batch_metadata.body)}{automation_info}",
             self._base_branch.name,
-            commit_branch,
+            f"{head}{commit_branch}",
         )
 
         EventHandler.get().handle(
@@ -104,24 +150,25 @@ class GithubRepo(GitRepo):
         )
 
         # Add labels
-        labels = batch_metadata.get("labels", [])
+        labels = deepcopy(batch_metadata.labels)
         labels.extend(self.labels)
         if labels:
             pull_request.add_labels(labels)
 
         # Request reviewers
-        reviewers = batch_metadata.get("reviewers", [])
+        reviewers = deepcopy(batch_metadata.reviewers)
         reviewers.extend(self.reviewers)
-        team_reviewers = batch_metadata.get("team_reviewers", [])
+        team_reviewers = deepcopy(batch_metadata.team_reviewers)
         team_reviewers.extend(self.team_reviewers)
         if reviewers or team_reviewers:
             pull_request.add_reviewers(reviewers, team_reviewers)
 
-    def get_automation_info(self, batch: Batch) -> str:
+    def get_automation_info(self, schema: Optional[AutoTransformSchema], batch: Batch) -> str:
         """Gets information on automating with AutoTransform.
 
         Args:
-            batch (Batch): The Batch the change is being made for.
+            schema (Optional[AutoTransformSchema]): The Schema making the Change.
+            batch (Batch): The Batch the Change is being made for.
 
         Returns:
             str: The text for automating.
@@ -136,12 +183,11 @@ class GithubRepo(GitRepo):
         automation_info_lines.append("Schema and batch information for the change below")
 
         # Add schema JSON
-        current_schema = autotransform.schema.current
-        if current_schema is not None:
+        if schema is not None:
             automation_info_lines.extend(
                 GithubRepo._get_encoded_json_lines(
                     "Schema",
-                    current_schema.bundle(),
+                    schema.bundle(),
                     GithubUtils.BEGIN_SCHEMA,
                     GithubUtils.END_SCHEMA,
                 )
@@ -196,7 +242,7 @@ class GithubRepo(GitRepo):
             Sequence[GithubChange]: The outstanding Changes against the Repo.
         """
 
-        pulls = GithubUtils.get(self.full_github_name).get_open_pull_requests(self.base_branch_name)
+        pulls = GithubUtils.get(self.full_github_name).get_open_pull_requests(self.base_branch)
         authenticated_user_id = GithubUtils.get(self.full_github_name).get_user_id()
         return [
             GithubChange(
