@@ -8,8 +8,7 @@
 # @black_format
 
 """The heart of AutoTransform, AutoTransformSchemas represent all information
-required to fully execute a change.
-"""
+required to fully execute a change."""
 
 from __future__ import annotations
 
@@ -87,9 +86,8 @@ class AutoTransformSchema(ComponentModel):
         # Get Items
         event_handler.handle(DebugEvent({"message": "Begin get_items"}))
         all_items = self.input.get_items()
-        event_handler.handle(
-            DebugEvent({"message": f"Items: {json.dumps([item.bundle() for item in all_items])}"})
-        )
+        item_str = "\n".join([f"{item!r}," for item in all_items])
+        event_handler.handle(DebugEvent({"message": f"Items: [\n{item_str}\n]"}))
 
         # Filter Items
         event_handler.handle(DebugEvent({"message": "Begin filters"}))
@@ -99,18 +97,16 @@ class AutoTransformSchema(ComponentModel):
             for cur_filter in self.filters:
                 if not cur_filter.is_valid(item):
                     is_valid = False
-                    event = DebugEvent(
-                        {"message": f"[{cur_filter}] Invalid Item: {json.dumps(item.bundle())}"}
-                    )
+                    event = DebugEvent({"message": f"[{cur_filter}] Invalid Item: {item!r}"})
                     event_handler.handle(event)
                     break
             if is_valid:
                 valid_items.append(item)
-        event_handler.handle(
-            DebugEvent(
-                {"message": f"Valid items: {json.dumps([item.bundle() for item in valid_items])}"}
-            )
-        )
+        if valid_items:
+            valid_item_str = "\n".join([f"{item!r}," for item in valid_items])
+            event_handler.handle(DebugEvent({"message": f"Valid items: [\n{valid_item_str}\n]"}))
+        else:
+            event_handler.handle(DebugEvent({"message": "No valid items."}))
 
         # Batch Items
         event_handler.handle(DebugEvent({"message": "Begin batching"}))
@@ -124,7 +120,7 @@ class AutoTransformSchema(ComponentModel):
 
         return batches
 
-    def execute_batch(self, batch: Batch, change: Optional[Change] = None) -> None:
+    def execute_batch(self, batch: Batch, change: Optional[Change] = None) -> bool:
         """Executes changes for a batch, including setting up the Repo, running the Transformer,
         checking all Validators, running Commands, submitting changes if present, and rewinding
         the Repo if changes are submitted. Note: this function is not thread safe.
@@ -135,6 +131,9 @@ class AutoTransformSchema(ComponentModel):
 
         Raises:
             ValidationError: If one of the Schema's Validators fails raises an exception.
+
+        Returns:
+            bool: Whether the batch triggered a submission.
         """
 
         autotransform.schema.current = self
@@ -151,6 +150,11 @@ class AutoTransformSchema(ComponentModel):
         if self.repo is not None:
             event_handler.handle(DebugEvent({"message": "Clean repo"}))
             self.repo.rewind(batch)
+            if change is None and self.repo.has_outstanding_change(batch):
+                event_handler.handle(
+                    DebugEvent({"message": "Skipping batch with outstanding change"})
+                )
+                return False
 
         # Execute transformation
         result = self.transformer.transform(batch)
@@ -180,6 +184,7 @@ class AutoTransformSchema(ComponentModel):
             event_handler.handle(DebugEvent({"message": f"Running command {command}"}))
             command.run(batch, result)
 
+        submitted = False
         # Handle repo state, submitting changes if present and reseting the repo
         if self.repo is not None:
             event_handler.handle(DebugEvent({"message": "Checking for changes"}))
@@ -189,20 +194,19 @@ class AutoTransformSchema(ComponentModel):
                 self.repo.submit(batch, result, change=change)
                 event_handler.handle(DebugEvent({"message": "Rewinding repo"}))
                 self.repo.rewind(batch)
+                submitted = True
             else:
                 if change is not None:
                     event_handler.handle(
-                        DebugEvent(
-                            {
-                                "message": f"Abandoning Change ({str(change)}) "
-                                + "due to no changes in update."
-                            }
-                        )
+                        DebugEvent({"message": "No changes in update, abandoning"})
                     )
-                    change.abandon()
+
+                    # pylint: disable=protected-access
+                    change._abandon()
                 event_handler.handle(DebugEvent({"message": "No changes found"}))
         event_handler.handle(DebugEvent({"message": "Finish batch"}))
         autotransform.schema.current = None
+        return submitted
 
     def run(self):
         """Fully run a given Schema including getting and executing all Batches.
@@ -210,8 +214,18 @@ class AutoTransformSchema(ComponentModel):
 
         autotransform.schema.current = self
         batches = self.get_batches()
+        num_submissions = 0
         for batch in batches:
-            self.execute_batch(batch)
+            if (
+                self.config.max_submissions is not None
+                and num_submissions >= self.config.max_submissions
+            ):
+                EventHandler.get().handle(
+                    DebugEvent({"message": f"Max submissions reached: {num_submissions}"})
+                )
+                break
+            if self.execute_batch(batch):
+                num_submissions += 1
         autotransform.schema.current = None
 
     @staticmethod
