@@ -15,13 +15,19 @@ import subprocess
 from argparse import ArgumentParser, Namespace
 from typing import Optional, Tuple
 
+from autotransform.config import (
+    CONFIG_FILE_NAME,
+    get_cwd_config_dir,
+    get_repo_config_dir,
+    get_repo_config_relative_path,
+)
 from autotransform.config.config import Config
-from autotransform.config.default import DefaultConfigFetcher
 from autotransform.repo.base import RepoName
 from autotransform.runner.base import Runner
 from autotransform.runner.github import GithubRunner
 from autotransform.schema.schema import AutoTransformSchema
-from autotransform.util.console import choose_yes_or_no, get_str, info
+from autotransform.util.console import choose_yes_or_no, info
+from autotransform.util.enums import SchemaType
 from autotransform.util.manager import Manager
 from autotransform.util.package import get_config_dir, get_examples_dir
 from autotransform.util.scheduler import Scheduler
@@ -31,7 +37,7 @@ def add_args(parser: ArgumentParser) -> None:
     """Adds the args to a subparser that are required to initialize AutoTransform.
 
     Args:
-        parser (ArgumentParser): The parser for the schema run.
+        parser (ArgumentParser): The parser for the initialization.
     """
 
     parser.add_argument(
@@ -112,10 +118,8 @@ def initialize_workflows(repo_dir: str, examples_dir: str, prev_config: Optional
         prev_config (Optional[Config]): Previously input Config.
     """
 
-    bot_name = get_str("Enter the name of the account used for automation: ")
-    bot_email = get_str("Enter the email of the account used for automation: ")
     component_directory = prev_config.component_directory if prev_config is not None else None
-    relative_config_dir = DefaultConfigFetcher.get_repo_config_relative_path()
+    relative_config_dir = get_repo_config_relative_path()
 
     workflows = [
         "autotransform.manage.yml",
@@ -127,8 +131,6 @@ def initialize_workflows(repo_dir: str, examples_dir: str, prev_config: Optional
         with open(f"{examples_dir}/workflows/{workflow}", "r", encoding="UTF-8") as workflow_file:
             workflow_text = workflow_file.read()
 
-        workflow_text = workflow_text.replace("<BOT EMAIL>", bot_email)
-        workflow_text = workflow_text.replace("<BOT NAME>", bot_name)
         workflow_text = workflow_text.replace("<CONFIG DIR>", relative_config_dir)
 
         if component_directory is not None:
@@ -161,7 +163,7 @@ def initialize_repo(
     """
 
     examples_dir = get_examples_dir()
-    repo_config_dir = DefaultConfigFetcher.get_repo_config_dir()
+    repo_config_dir = get_repo_config_dir()
 
     github = use_github
     if github is None:
@@ -192,8 +194,10 @@ def initialize_repo(
 
     # Set up the sample schema
     use_sample_schema = simple or choose_yes_or_no("Would you like to include the sample schema?")
+    schema_map = {}
     if use_sample_schema:
         sample_schema_path = f"{examples_dir}/schemas/black_format.json"
+        schema_map["Black Format"] = {"type": SchemaType.FILE, "target": sample_schema_path}
         with open(sample_schema_path, "r", encoding="UTF-8") as sample_schema_file:
             schema = AutoTransformSchema.from_data(json.loads(sample_schema_file.read()))
         schema.repo = manager.repo  # pylint: disable=protected-access
@@ -217,6 +221,13 @@ def initialize_repo(
         requirements_file.write(requirements)
         requirements_file.flush()
 
+    # Set up schema map file
+    schema_map_path = f"{repo_config_dir}/schema_map.json"
+    os.makedirs(os.path.dirname(schema_map_path), exist_ok=True)
+    with open(schema_map_path, "w+", encoding="UTF-8") as schema_map_file:
+        schema_map_file.write(json.dumps(schema_map))
+        schema_map_file.flush()
+
     # Set up manage file
     manager_path = f"{repo_config_dir}/manager.json"
     manager.write(manager_path)
@@ -247,7 +258,7 @@ def initialize_command_main(args: Namespace) -> None:
     simple = args.simple
     github = args.github
 
-    user_config_path = f"{get_config_dir()}/{DefaultConfigFetcher.FILE_NAME}"
+    user_config_path = f"{get_config_dir()}/{CONFIG_FILE_NAME}"
     config, github = initialize_config(
         user_config_path, "user", None, simple=simple, use_github=github
     )
@@ -264,18 +275,14 @@ def initialize_command_main(args: Namespace) -> None:
         setup_repo = False
 
     if setup_repo:
-        repo_config_path = (
-            f"{DefaultConfigFetcher.get_repo_config_dir()}/{DefaultConfigFetcher.FILE_NAME}"
-        )
+        repo_config_path = f"{get_repo_config_dir()}/{CONFIG_FILE_NAME}"
         config, github = initialize_config(
             repo_config_path, "repo", config, simple=simple, use_github=github
         )
         initialize_repo(repo_dir, config, simple=simple, use_github=github)
 
     if repo_dir == "" and choose_yes_or_no("Set up configuration for current working directory?"):
-        cwd_config_path = (
-            f"{DefaultConfigFetcher.get_cwd_config_dir()}/{DefaultConfigFetcher.FILE_NAME}"
-        )
+        cwd_config_path = f"{get_cwd_config_dir()}/{CONFIG_FILE_NAME}"
         initialize_config(
             cwd_config_path, "current working directory", config, simple=simple, use_github=github
         )
