@@ -15,9 +15,11 @@ import json
 import os
 from datetime import datetime
 from enum import Enum
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Type
 
-from autotransform.config.default import DefaultConfigFetcher
+from pydantic import validator
+
+from autotransform.config import get_repo_config_relative_path
 from autotransform.event.debug import DebugEvent
 from autotransform.event.handler import EventHandler
 from autotransform.event.schedulerun import ScheduleRunEvent
@@ -40,13 +42,7 @@ from autotransform.util.console import (
     input_int,
     input_ints,
 )
-
-
-class SchemaType(str, Enum):
-    """Possible types of Schemas to use."""
-
-    BUILDER = "builder"
-    FILE = "file"
+from autotransform.util.enums import SchemaType
 
 
 class RepeatSetting(str, Enum):
@@ -61,16 +57,16 @@ class SchemaScheduleSettings(ComponentModel):
 
     Attributes:
         repeats (RepeatSetting): How often the Schema will be run, daily or weekly.
-        hour_of_day (int): The hour of the day to run the Schema, 0-23.
+        hour_of_day (int, optional): The hour of the day to run the Schema, 0-23. Defaults to 0.
         day_of_week (Optional[int], optional): The day of the week to run a weekly Schema.
-            Defaults to None.
+            Defaults to 0.
         shard_filter (Optional[ShardingSettings], optional): A shard filter to use for sharding
             the inputs across multiple runs. Defaults to None.
     """
 
     repeats: RepeatSetting
-    hour_of_day: int
-    day_of_week: Optional[int] = None
+    hour_of_day: int = 0
+    day_of_week: Optional[int] = 0
     shard_filter: Optional[ShardFilter] = None
 
     def should_run(self, hour_of_day: int, day_of_week: int) -> bool:
@@ -100,10 +96,10 @@ class SchemaScheduleSettings(ComponentModel):
         """
 
         repeats = RepeatSetting(data["repeats"])
-        hour_of_day = data["hour_of_day"]
+        hour_of_day = data.get("hour_of_day", 0)
         assert isinstance(hour_of_day, int)
         assert hour_of_day in range(24)
-        day_of_week = data.get("day_of_week", None)
+        day_of_week = data.get("day_of_week", 0)
         if day_of_week is not None:
             assert isinstance(day_of_week, int)
             assert day_of_week in range(7)
@@ -180,15 +176,38 @@ class ScheduledSchema(ComponentModel):
     """A Schema that is scheduled for automatic runs.
 
     Attributes:
-        type (SchemaType): The type of Schema that is specified, file or builder.
-        target (str): The Schema that is being scheduled.
+        schema_name (str): The Schema that is being scheduled.
         schedule (SchemaScheduleSettings): The settings used to determine when to run the Schema.
+        max_submissions (Optional[int], optional): The max number of submissions from a given
+            scheduled run. No limit if None. Defaults to None.
     """
 
-    type: SchemaType
-    target: str
+    schema_name: str
     schedule: SchemaScheduleSettings
 
+    max_submissions: Optional[int] = None
+
+    # pylint: disable=invalid-name
+    @validator("max_submissions")
+    @classmethod
+    def max_submissions_is_positive(cls: Type[ScheduledSchema], v: Optional[int]) -> Optional[int]:
+        """Validates that max submissions is positive.
+
+        Args:
+            cls (Type[ScheduledSchema]): The ScheduledSchema class.
+            v (int): The maximum number of submissions.
+
+        Raises:
+            ValueError: Raised if the maximum number of submissions is not positive.
+
+        Returns:
+            Optional[int]: The unmodified maximum number of submissions.
+        """
+
+        if v is not None and v < 1:
+            raise ValueError(f"Maximum number of submissions must be positive, {v} provided")
+        return v
+
     @staticmethod
     def from_data(data: Dict[str, Any]) -> ScheduledSchema:
         """Produces an instance of the ScheduledSchema from decoded data.
@@ -200,11 +219,15 @@ class ScheduledSchema(ComponentModel):
             ScheduledSchema: An instance of the ScheduledSchema.
         """
 
-        schema_type = SchemaType(data["type"])
-        target = data["target"]
-        assert isinstance(target, str)
+        schema_name = data["schema_name"]
+        assert isinstance(schema_name, str)
         schedule = SchemaScheduleSettings.from_data(data["schedule"])
-        return ScheduledSchema(type=schema_type, target=target, schedule=schedule)
+        max_submissions = data.get("max_submissions", None)
+        if max_submissions is not None:
+            assert isinstance(max_submissions, int)
+        return ScheduledSchema(
+            schema_name=schema_name, schedule=schedule, max_submissions=max_submissions
+        )
 
     @staticmethod
     def from_console() -> ScheduledSchema:
@@ -221,10 +244,16 @@ class ScheduledSchema(ComponentModel):
             [(SchemaType.FILE, ["file", "f"]), (SchemaType.BUILDER, ["builder", "b"])],
         )
 
+        if choose_yes_or_no("Would you like to limit the maximum number of submissions?"):
+            max_submissions = input_int("Enter the maximum number of submissions", min_val=1)
+        else:
+            max_submissions = None
+
         return ScheduledSchema(
             target=target,
             type=schema_type,
             schedule=SchemaScheduleSettings.from_console(),
+            max_submissions=max_submissions,
         )
 
 
@@ -266,49 +295,42 @@ class Scheduler(ComponentModel):
 
         if day_of_week in self.excluded_days:
             EventHandler.get().handle(
-                DebugEvent(
-                    {
-                        "message": f"Day {day_of_week} is excluded, skipping run",
-                    }
-                )
+                DebugEvent({"message": f"Day {day_of_week} is excluded, skipping run"})
             )
             return
 
-        for scheduled_schema in self.schemas:
-            # Get the Schema
-            if scheduled_schema.type == SchemaType.BUILDER:
-                try:
-                    schema = json.loads(scheduled_schema.target)
-                except json.JSONDecodeError:
-                    schema = {"name": scheduled_schema.target}
-                if isinstance(schema, str):
-                    schema = {"name": schema}
-                schema = schema_builder_factory.get_instance(schema).build()
-            else:
-                with open(scheduled_schema.target, "r", encoding="UTF-8") as schema_file:
-                    schema = AutoTransformSchema.from_data(json.loads(schema_file.read()))
+        map_file_path = f"{get_repo_config_relative_path()}/schema_map.json"
+        with open(map_file_path, "r", encoding="UTF-8") as map_file:
+            schema_map = json.loads(map_file.read())
 
+        for scheduled_schema in self.schemas:
             # Check if should run
             if not scheduled_schema.schedule.should_run(hour_of_day, day_of_week):
                 EventHandler.get().handle(
-                    DebugEvent({"message": f"Skipping run of schema: {schema.config.schema_name}"})
+                    DebugEvent(
+                        {"message": f"Skipping run of schema: {scheduled_schema.schema_name}"}
+                    )
                 )
                 continue
+            schema_data = schema_map[scheduled_schema.schema_name]
+            schema_type = SchemaType(schema_data["type"])
+            if schema_type == SchemaType.BUILDER:
+                schema = schema_builder_factory.get_instance(
+                    {"name": schema_data["target"]}
+                ).build()
+            else:
+                with open(schema_data["target"], "r", encoding="UTF-8") as schema_file:
+                    schema = AutoTransformSchema.from_data(json.loads(schema_file.read()))
             shard_filter = scheduled_schema.schedule.shard_filter
             if shard_filter is not None:
                 if scheduled_schema.schedule.repeats == RepeatSetting.DAILY:
                     shard_filter.valid_shard = elapsed_days % shard_filter.num_shards
                 else:
                     shard_filter.valid_shard = (elapsed_days // 7) % shard_filter.num_shards
-                EventHandler.get().handle(
-                    DebugEvent(
-                        {
-                            "message": f"Sharding: valid = {shard_filter.valid_shard}, "
-                            + f"num = {shard_filter.num_shards}",
-                        }
-                    )
-                )
-                schema.add_filter(shard_filter)
+                EventHandler.get().handle(DebugEvent({"message": f"Sharding: {shard_filter!r}"}))
+                schema.filters.append(shard_filter)
+            if scheduled_schema.max_submissions is not None:
+                schema.config.max_submissions = scheduled_schema.max_submissions
             EventHandler.get().handle(ScheduleRunEvent({"schema_name": schema.config.schema_name}))
             self.runner.run(schema)
 
@@ -425,7 +447,7 @@ class Scheduler(ComponentModel):
 
         # Gets Schemas
         if use_sample_schema:
-            relative_path = DefaultConfigFetcher.get_repo_config_relative_path()
+            relative_path = get_repo_config_relative_path()
             schemas = [
                 ScheduledSchema(
                     type=SchemaType.FILE,
