@@ -17,12 +17,7 @@ from enum import Enum
 from typing import Any, ClassVar, Dict, Mapping, Optional
 
 from autotransform.batcher.base import Batch
-from autotransform.util.component import (
-    ComponentFactory,
-    ComponentImport,
-    ComponentModel,
-    NamedComponent,
-)
+from autotransform.util.component import ComponentFactory, ComponentImport, NamedComponent
 
 
 class ValidationResultLevel(str, Enum):
@@ -56,21 +51,23 @@ class ValidationResultLevel(str, Enum):
     def __lt__(self, other: object) -> bool:
         return self.compare(str(other.value) if isinstance(other, Enum) else str(other)) < 0
 
-    def __lte__(self, other: object) -> bool:
+    def __le__(self, other: object) -> bool:
         return self.compare(str(other.value) if isinstance(other, Enum) else str(other)) <= 0
 
     def __gt__(self, other: object) -> bool:
         return self.compare(str(other.value) if isinstance(other, Enum) else str(other)) > 0
 
-    def __gte__(self, other: object) -> bool:
-        return self.compare(other.value if isinstance(other, Enum) else str(other)) >= 0
+    def __ge__(self, other: object) -> bool:
+        return self.compare(str(other.value) if isinstance(other, Enum) else str(other)) >= 0
 
 
-class ValidationResult(ComponentModel):
+@dataclass(frozen=True, kw_only=True)
+class ValidationResult:
     """Represents the result of an attempt at validation.
 
     Attributes:
         level (ValidationResultLevel): The level of the validation issue raised.
+        validator (Validator): The Validator that returned this result.
         message (Optional[str], optional): The message associated with the validation
             result. Defaults to None.
     """
@@ -120,7 +117,7 @@ class Validator(NamedComponent):
 
         Returns:
             ValidationResult: The result of the validation check indicating the severity of any
-                validation failures as well as an associated message
+                validation failures as well as an associated message.
         """
 
 
